@@ -2440,135 +2440,6 @@ test_socket_timeout (TestConnection *test,
   g_assert_error (test->server_error, G_TLS_ERROR, G_TLS_ERROR_NOT_TLS);
 }
 
-typedef struct {
-  TestConnection *test;
-  gboolean peer_certificate_notified;
-  gboolean peer_certificate_errors_notified;
-} NotifyTestData;
-
-static gboolean
-on_accept_certificate_peer_certificate_notify (GTlsConnection       *conn,
-                                               GTlsCertificate      *cert,
-                                               GTlsCertificateFlags  errors,
-                                               NotifyTestData       *data)
-{
-  TestConnection *test = data->test;
-
-  g_assert_true (G_IS_TLS_CERTIFICATE (cert));
-
-  /* We guarantee these props are not set until after the handshake. */
-  g_assert_null (g_tls_connection_get_peer_certificate (conn));
-  g_assert_cmpint (g_tls_connection_get_peer_certificate_errors (conn), ==, 0);
-
-  g_assert_false (data->peer_certificate_notified);
-  g_assert_false (data->peer_certificate_errors_notified);
-
-  return errors == test->accept_flags;
-}
-
-static void
-on_peer_certificate_notify (GTlsConnection *conn,
-                            GParamSpec     *pspec,
-                            gboolean       *notified)
-{
-  *notified = TRUE;
-}
-
-static void
-on_peer_certificate_errors_notify (GTlsConnection *conn,
-                                   GParamSpec     *pspec,
-                                   gboolean       *notified)
-{
-  *notified = TRUE;
-}
-
-static void
-test_peer_certificate_notify (TestConnection *test,
-                              gconstpointer   data)
-{
-  NotifyTestData notify_data = { test, FALSE, FALSE };
-  GIOStream *connection;
-  GError *error = NULL;
-
-  connection = start_async_server_and_connect_to_it (test, G_TLS_AUTHENTICATION_NONE);
-  test->client_connection = g_tls_client_connection_new (connection, test->identity, &error);
-  g_assert_no_error (error);
-  g_object_unref (connection);
-
-  /* For this test, we need validation to fail to ensure that the
-   * accept-certificate signal gets emitted.
-   */
-  g_tls_client_connection_set_validation_flags (G_TLS_CLIENT_CONNECTION (test->client_connection),
-                                                G_TLS_CERTIFICATE_VALIDATE_ALL);
-
-  g_signal_connect (test->client_connection, "accept-certificate",
-                    G_CALLBACK (on_accept_certificate_peer_certificate_notify), &notify_data);
-  g_signal_connect (test->client_connection, "notify::peer-certificate",
-                    G_CALLBACK (on_peer_certificate_notify), &notify_data.peer_certificate_notified);
-  g_signal_connect (test->client_connection, "notify::peer-certificate-errors",
-                    G_CALLBACK (on_peer_certificate_errors_notify), &notify_data.peer_certificate_errors_notified);
-
-  read_test_data_async (test);
-  g_main_loop_run (test->loop);
-  wait_until_server_finished (test);
-
-  g_assert_true (notify_data.peer_certificate_notified);
-  g_assert_true (notify_data.peer_certificate_errors_notified);
-
-  /* These properties should only be set after a *successful* handshake. */
-  g_assert_null (g_tls_connection_get_peer_certificate (G_TLS_CONNECTION (test->client_connection)));
-  g_assert_cmpint (g_tls_connection_get_peer_certificate_errors (G_TLS_CONNECTION (test->client_connection)), ==, 0);
-
-  g_assert_error (test->read_error, G_TLS_ERROR, G_TLS_ERROR_BAD_CERTIFICATE);
-
-#ifdef BACKEND_IS_GNUTLS
-  g_assert_error (test->server_error, G_TLS_ERROR, G_TLS_ERROR_NOT_TLS);
-#elif defined(BACKEND_IS_OPENSSL)
-  /* FIXME: This is not OK. There should be an error here. */
-  g_assert_no_error (test->server_error);
-#endif
-
-  /* Now do it all again, this time with a successful connection. */
-
-  g_clear_object (&test->service);
-  g_clear_object (&test->server_connection);
-  g_clear_object (&test->client_connection);
-
-  g_clear_error (&test->read_error);
-  g_clear_error (&test->server_error);
-
-  notify_data.peer_certificate_notified = FALSE;
-  notify_data.peer_certificate_errors_notified = FALSE;
-
-  connection = start_async_server_and_connect_to_it (test, G_TLS_AUTHENTICATION_NONE);
-  test->client_connection = g_tls_client_connection_new (connection, test->identity, &error);
-  g_assert_no_error (error);
-  g_object_unref (connection);
-
-  g_signal_connect (test->client_connection, "accept-certificate",
-                    G_CALLBACK (on_accept_certificate_peer_certificate_notify), &notify_data);
-  g_signal_connect (test->client_connection, "notify::peer-certificate",
-                    G_CALLBACK (on_peer_certificate_notify), &notify_data.peer_certificate_notified);
-  g_signal_connect (test->client_connection, "notify::peer-certificate-errors",
-                    G_CALLBACK (on_peer_certificate_errors_notify), &notify_data.peer_certificate_errors_notified);
-
-  /* Disable validation so we have a successful handshake. */
-  g_tls_client_connection_set_validation_flags (G_TLS_CLIENT_CONNECTION (test->client_connection),
-                                                0);
-  read_test_data_async (test);
-  g_main_loop_run (test->loop);
-  wait_until_server_finished (test);
-
-  g_assert_true (notify_data.peer_certificate_notified);
-  g_assert_true (notify_data.peer_certificate_errors_notified);
-
-  g_assert_true (G_IS_TLS_CERTIFICATE (g_tls_connection_get_peer_certificate (G_TLS_CONNECTION (test->client_connection))));
-  g_assert_cmpint (g_tls_connection_get_peer_certificate_errors (G_TLS_CONNECTION (test->client_connection)), !=, 0);
-
-  g_assert_no_error (test->read_error);
-  g_assert_no_error (test->server_error);
-}
-
 int
 main (int   argc,
       char *argv[])
@@ -2655,8 +2526,6 @@ main (int   argc,
               setup_connection, test_sync_op_during_handshake, teardown_connection);
   g_test_add ("/tls/" BACKEND "/connection/socket-timeout", TestConnection, NULL,
               setup_connection, test_socket_timeout, teardown_connection);
-  g_test_add ("/tls/" BACKEND "/connection/peer-certificate-notify", TestConnection, NULL,
-              setup_connection, test_peer_certificate_notify, teardown_connection);
 
   ret = g_test_run ();
 
